---
title: 본인인증
category: 서비스 종류 (결제대행사별 지원서비스) > 본인인증 > 본인인증
seo:
  title: 본인인증
  description: >-
    본인 인증 서비스는 결제와 무관하게 단독으로도 연동 가능하며, 본인확인 과정이 필요하신 경우에도 선택적으로 서비스 사용이 가능합니다.
    포트원에서 제공하는 인증수단을 모두 확인해보세요.
tags:
  - KG이니시스
  - 다날
  - NHN KCP
  - 본인인증
pgCompanies:
  - NHN KCP
  - 다날
  - KG이니시스
searchTags:
  - 통합인증
  - PASS
  - 본인인증
  - 휴대폰 본인인증
  - PASS인증
  - 휴대폰인증
  - 카카오인증계약
  - 카카오인증방법
  - 문자본인인증
  - 인증서비스 지원
  - 인증이용방법
  - 인증서비스방법
  - sms본인인증이용
---

<Callout content="포트원에서 제공 해드리는 인증 수단을 안내드립니다.
고객의 본인 확인 여부가 필요하신 경우 사용할 수 있으며 결제 서비스와 무관하여 단독으로 사용이 가능하며 단독으로 사용하실 때에도 결제대행사와의 계약은 필수입니다." />

## <Highlight text="휴대폰(PASS앱/SMS)본인인증" />

본인 명의로 개통한 휴대폰을 이용하여 ‘본인확인정보’를 입력하는 인증절차를 거쳐 본인 여부를 확인해주는 서비스로, PASS앱을 통한 문자(SMS) 인증이 가능합니다.

휴대폰(PASS앱/SMS)**본인인증** 서비스를 지원하는 결제대행사는 **다날, NHN KCP** 입니다.

<Callout content="SMS 본인인증은 PG사 정책상 **테스트환경 지원이 불가**하여 실제 PG사와 계약을 맺으신 후 실제 연동 KEY로 연동 테스트가 가능합니다." title="참고사항" icon="💡" />





## <Highlight text="통합인증" />

민간인증서를 기반으로 간편인증과 전자서명을 통합으로 제공하는 서비스로 네이버, 카카오, 금융인증서, PASS 등의 인증서로 통합적으로 인증이 가능합니다.

통합인증 서비스를 지원하는 결제대행사는 **KG이니시스** 입니다.

<Callout content="- 이용 가능 수단:  네이버 / PASS / 페이코 / TOSS / 카카오 / 금융인증서 / 신한 / KB모바일 / 삼성패스
- 통합인증 응답값 중 내국인/외국인(foreigner), 통신사, 성별(gender) 정보는 응답되지 않습니다.
- 카카오 인증의 경우, CI 정보를 제공하나 KG이니시스와 계약시 별도 서류 작성 절차가 필요합니다." title="참고사항" icon="💡" />

인증 기관별 입점제한 기준

- 네이버,토스,페이코,카카오,신한,KB모바일,삼성패스는 성인몰인 경우 전면 제한되며,PASS는 부분적으로 가능합니다.
- 네이버, PASS(패스), 토스, 카카오, 신한, KB모바일, 삼성패스: 성인업종 전체 불가
- PASS(패스): 미풍양속(성인, 도박, 주류)을 저해하는 사이트 제한 (정보제공, 미팅/채팅에 한하여 진행 가능)

![](</uploads/결제수단/본인인증-종류/Untitled (13).png>)![](</uploads/결제수단/본인인증-종류/Untitled (14).png>)
